@@ -1,3 +1,4 @@
+import os
 import time
 import datetime
 from dateutil.relativedelta import relativedelta
@@ -127,7 +128,18 @@ class DataSource:
 
     def _get_query_list(self, layer_name, query_name=None):
         folder_path = self._build_folder_path(layer_name)
-        config = yaml.load(self.load_file(folder_path + "config.yaml"), Loader=yaml.FullLoader)
+
+        jinja_env = jinja2.Environment()
+
+        params = {}
+        if os.path.isfile(folder_path + "params.yaml"):
+            params = yaml.load(
+                jinja_env.from_string(open(folder_path + "params.yaml").read()).render(),
+                Loader=yaml.FullLoader)
+        config = yaml.load(
+            jinja_env.from_string(open(folder_path + "config.yaml").read()).render(params),
+            Loader=yaml.FullLoader)
+
         queries = config.get("queries")
         schema_name = config.get("schema_name") if config.get("schema_name") else (self.layer_type + "_" + layer_name)
         schema_name = self.schema_prefix + '_' + schema_name if self.schema_prefix else schema_name
